@@ -14,7 +14,6 @@ import java.util.List;
 import java.util.Vector;
 
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 
 /**
  * ConfClient provides a client-side cache for a specified list of directories
@@ -38,7 +37,7 @@ public class ConfClient extends GObject {
 	 */
 	private Hashtable listeners = null;
 	
-	private ConfClient(Handle handle) {
+	private ConfClient(int handle) {
 		super(handle);
 	}
 	
@@ -103,8 +102,8 @@ public class ConfClient extends GObject {
 	}
 
 	/**
-	 * Removes a listener.
-	 * @see #addListener(ConfClientListener, String)
+	 * Removes a listener
+	 * @see #addListener(ConfClientListener)
 	 */
 	public void removeListener(ConfClientListener listener, String nameSpace) {
 		int id = -1;
@@ -168,11 +167,12 @@ public class ConfClient extends GObject {
 	/**
 	 * Get the value of a configuration key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public ConfValue get(String key) throws ConfException {
 		int err = -1;
-		Handle hndl = gconf_client_get(getHandle(), key, new int[] {err});
+		int hndl = gconf_client_get(getHandle(), key, new int[] {err});
 		checkError(err);
 		return new ConfValue(hndl);
 	}
@@ -182,11 +182,12 @@ public class ConfClient extends GObject {
 	 * @param key
 	 * @param locale
 	 * @param useSchemaDefault
+	 * @return
 	 * @throws ConfException
 	 */
 	public ConfEntry getEntry(String key, String locale, boolean useSchemaDefault) throws ConfException {
 		int err = -1;
-		Handle hndl = gconf_client_get_entry(getHandle(), key, locale, useSchemaDefault, new int[] {err});
+		int hndl = gconf_client_get_entry(getHandle(), key, locale, useSchemaDefault, new int[] {err});
 		checkError(err);
 		return new ConfEntry(hndl);
 	}
@@ -196,11 +197,12 @@ public class ConfClient extends GObject {
 	 * a schema associated and the schema exists and the schema contains
 	 * a default value.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public ConfValue getDefaultFromSchema(String key) throws ConfException {
 		int err = -1;
-		Handle hndl = gconf_client_get_default_from_schema(getHandle(), key, new int[] {err});
+		int hndl = gconf_client_get_default_from_schema(getHandle(), key, new int[] {err});
 		checkError(err);
 		return new ConfValue(hndl);
 	}
@@ -208,6 +210,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Unsets the value of the provided key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean unset(String key) throws ConfException {
@@ -220,11 +223,12 @@ public class ConfClient extends GObject {
 	/**
 	 * Get a list of all ConfEntries in the provided direcotry.
 	 * @param dir
+	 * @return
 	 * @throws ConfException
 	 */
 	public List getAllEntries(String dir) throws ConfException {
 		int err = -1;
-		Handle [] array = gconf_client_all_entries(getHandle(), dir, new int[] {err});
+		int [] array = gconf_client_all_entries(getHandle(), dir, new int[] {err});
 		checkError(err);
 		if (array == null)
 			return null;
@@ -238,6 +242,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Get a list of the subdirectories in the provided directory.
 	 * @param dir
+	 * @return
 	 * @throws ConfException
 	 */
 	public List getAllDirs(String dir) throws ConfException {
@@ -267,6 +272,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Check to see if a directory exists in the GConf database.
 	 * @param dir
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean dirExists(String dir) throws ConfException {
@@ -279,6 +285,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Request the double value stored at the provided key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public double getDouble(String key) throws ConfException {
@@ -291,6 +298,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Request the int value stored at the provided key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public int getInt(String key) throws ConfException {
@@ -303,6 +311,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Request the String value stored at the provided key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public String getString(String key) throws ConfException {
@@ -315,6 +324,7 @@ public class ConfClient extends GObject {
 	/**
 	 * Request the boolean value stored at the provided key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean getBoolean(String key) throws ConfException {
@@ -327,11 +337,12 @@ public class ConfClient extends GObject {
 	/**
 	 * Request the ConfSchema value stored at the provided key.
 	 * @param key
+	 * @return
 	 * @throws ConfException
 	 */
 	public ConfSchema getSchema(String key) throws ConfException {
 		int err = -1;
-		Handle ret = gconf_client_get_schema(getHandle(), key, new int[] {err});
+		int ret = gconf_client_get_schema(getHandle(), key, new int[] {err});
 		checkError(err);
 		return new ConfSchema(ret);
 	}
@@ -341,6 +352,7 @@ public class ConfClient extends GObject {
 	 * array is of the type provided.
 	 * @param key
 	 * @param listType
+	 * @return
 	 * @throws ConfException
 	 */
 	public Object[] getList(String key, ConfValueType listType) throws ConfException {
@@ -355,6 +367,7 @@ public class ConfClient extends GObject {
 	 * value.
 	 * @param key
 	 * @param value
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean setDouble(String key, double value) throws ConfException {
@@ -369,6 +382,7 @@ public class ConfClient extends GObject {
 	 * value.
 	 * @param key
 	 * @param value
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean setInt(String key, int value) throws ConfException {
@@ -383,6 +397,7 @@ public class ConfClient extends GObject {
 	 * value.
 	 * @param key
 	 * @param value
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean setString(String key, String value) throws ConfException {
@@ -397,6 +412,7 @@ public class ConfClient extends GObject {
 	 * value.
 	 * @param key
 	 * @param value
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean setBoolean(String key, boolean value) throws ConfException {
@@ -411,6 +427,7 @@ public class ConfClient extends GObject {
 	 * value.
 	 * @param key
 	 * @param value
+	 * @return
 	 * @throws ConfException
 	 */
 	public boolean setSchema(String key, ConfSchema value) throws ConfException {
@@ -425,7 +442,7 @@ public class ConfClient extends GObject {
 		return false;
 	}
 	
-	protected void notifyCallback(Handle e, String nameSpace) {
+	protected void notifyCallback(int e, String nameSpace) {
 		NotifyData nd = (NotifyData)listeners.get(nameSpace);
 		if (null == nd)
 			return;
@@ -444,43 +461,47 @@ public class ConfClient extends GObject {
 			throw new ConfException(error);
 	}
 
-
-	native static final protected Handle gconf_client_get_default();
-	native static final protected Handle gconf_client_get_for_engine(Handle engine);
-	native static final protected void gconf_client_add_dir(Handle client, String dir, int preloadType, int[] error);
-	native static final protected void gconf_client_remove_dir(Handle client, String dir, int[] error);
-	native final protected int gconf_client_notify_add(Handle client, String namespace, int[] error);
-	native static protected void gconf_client_notify_remove(Handle client, int cnxn);
-	native static final protected void gconf_client_clear_cache(Handle client);
-	native static final protected void gconf_client_preload(Handle client, String dirname, int type, int[] error);
-	native static final protected void gconf_client_set(Handle client, String key, Handle val, int[] error);
-	native static final protected Handle gconf_client_get(Handle client, String key, int[] error);
-	native static final protected Handle gconf_client_get_without_default(Handle client, String key, int[] error);
-	native static final protected Handle gconf_client_get_entry(Handle client, String key, String locale, boolean useSchemaDefault, int[] error);
-	native static final protected Handle gconf_client_get_default_from_schema(Handle client, String key, int[] error);
-	native static final protected boolean gconf_client_unset(Handle client, String key, int[] error);
-	native static final protected Handle[] gconf_client_all_entries(Handle client, String dir, int[] error);
-	native static final protected String[] gconf_client_all_dirs(Handle client, String dir, int[] error);
-	native static final protected void gconf_client_suggest_sync(Handle client, int[] error);
-	native static final protected boolean gconf_client_dir_exists(Handle client, String dir, int[] error);
-	native static final protected double gconf_client_get_float(Handle client, String key, int[] error);
-	native static final protected int gconf_client_get_int(Handle client, String key, int[] error);
-	native static final protected String gconf_client_get_string(Handle client, String key, int[] error);
-	native static final protected boolean gconf_client_get_bool(Handle client, String key, int[] error);
-	native static final protected Handle gconf_client_get_schema(Handle client, String key, int[] error);
-	native static final protected Object[] gconf_client_get_list(Handle client, String key, int listType, int[] error);
-	native static final protected boolean gconf_client_get_pair(Handle client, String key, int carType, int cdrType, int[] car, int[] cdr, int[] error);
-	native static final protected boolean gconf_client_set_float(Handle client, String key, double val, int[] error);
-	native static final protected boolean gconf_client_set_int(Handle client, String key, int val, int[] error);
-	native static final protected boolean gconf_client_set_string(Handle client, String key, String val, int[] error);
-	native static final protected boolean gconf_client_set_bool(Handle client, String key, boolean val, int[] error);
-	native static final protected boolean gconf_client_set_schema(Handle client, String key, Handle val, int[] error);
-	native static final protected boolean gconf_client_set_list(Handle client, String key, int listType, Object[] list, int[] error);
-	native static final protected boolean gconf_client_set_pair(Handle client, String key, int carType, int cdrType, int car, int cdr, int[] error);
-	native static final protected void gconf_client_value_changed(Handle client, String key, Handle value);
-
+	/****************************************
+	 * BEGINNING OF NATIVE CODE
+	 ****************************************/
+	native static final protected int gconf_client_get_default();
+	native static final protected int gconf_client_get_for_engine(int engine);
+	native static final protected void gconf_client_add_dir(int client, String dir, int preloadType, int[] error);
+	native static final protected void gconf_client_remove_dir(int client, String dir, int[] error);
+	native final protected int gconf_client_notify_add(int client, String namespace, int[] error);
+	native static protected void gconf_client_notify_remove(int client, int cnxn);
+	native static final protected void gconf_client_clear_cache(int client);
+	native static final protected void gconf_client_preload(int client, String dirname, int type, int[] error);
+	native static final protected void gconf_client_set(int client, String key, int val, int[] error);
+	native static final protected int gconf_client_get(int client, String key, int[] error);
+	native static final protected int gconf_client_get_without_default(int client, String key, int[] error);
+	native static final protected int gconf_client_get_entry(int client, String key, String locale, boolean useSchemaDefault, int[] error);
+	native static final protected int gconf_client_get_default_from_schema(int client, String key, int[] error);
+	native static final protected boolean gconf_client_unset(int client, String key, int[] error);
+	native static final protected int[] gconf_client_all_entries(int client, String dir, int[] error);
+	native static final protected String[] gconf_client_all_dirs(int client, String dir, int[] error);
+	native static final protected void gconf_client_suggest_sync(int client, int[] error);
+	native static final protected boolean gconf_client_dir_exists(int client, String dir, int[] error);
+	native static final protected double gconf_client_get_float(int client, String key, int[] error);
+	native static final protected int gconf_client_get_int(int client, String key, int[] error);
+	native static final protected String gconf_client_get_string(int client, String key, int[] error);
+	native static final protected boolean gconf_client_get_bool(int client, String key, int[] error);
+	native static final protected int gconf_client_get_schema(int client, String key, int[] error);
+	native static final protected Object[] gconf_client_get_list(int client, String key, int listType, int[] error);
+	native static final protected boolean gconf_client_get_pair(int client, String key, int carType, int cdrType, int[] car, int[] cdr, int[] error);
+	native static final protected boolean gconf_client_set_float(int client, String key, double val, int[] error);
+	native static final protected boolean gconf_client_set_int(int client, String key, int val, int[] error);
+	native static final protected boolean gconf_client_set_string(int client, String key, String val, int[] error);
+	native static final protected boolean gconf_client_set_bool(int client, String key, boolean val, int[] error);
+	native static final protected boolean gconf_client_set_schema(int client, String key, int val, int[] error);
+	native static final protected boolean gconf_client_set_list(int client, String key, int listType, Object[] list, int[] error);
+	native static final protected boolean gconf_client_set_pair(int client, String key, int carType, int cdrType, int car, int cdr, int[] error);
+	native static final protected void gconf_client_value_changed(int client, String key, int value);
+	/****************************************
+	 * END OF NATIVE CODE
+	 ****************************************/
 
 	static {
-		System.loadLibrary("gconfjni-2.8");
+		System.loadLibrary("gconfjava2.9");
 	}
 }
